import Api from '@/api';
import type { FormSchema } from '@/components/core/schema-form/';
import { debounce } from 'lodash-es';
import { nextTick, toRaw } from 'vue';
export const formSchemas: FormSchema<API.ProductDto>[] = [
  {
    field: 'name',
    component: 'Input',
    label: '产品名称',
    rules: [{ required: true, type: 'string' }],
    colProps: {
      span: 12,
    },
  },
  {
    field: 'companyId',
    component: 'Select',
    label: '所属公司',
    // componentProps: {
    //   request: async () => {
    //     const { items: result } = await Api.company.companyList({ pageSize: 100 });
    //     return result?.map((item) => ({ label: item.name, value: item.id }));
    //   },
    // },
    componentProps: ({ formInstance, schema }) => ({
      showSearch: true,
      filterOption: false,
      fieldNames: {
        label: 'label',
        value: 'value',
      },
      options: [],
      getPopupContainer: () => document.body,
      defaultActiveFirstOption: true,
      onChange: async (value, option) => {
        console.log('onChange');
        if (!value) {
          formInstance?.setFieldsValue({ companyId: undefined });
          const { items: result } = await Api.company.companyList({ pageSize: 100 });
          const newSchema = {
            field: schema.field,
            componentProps: {
              options: result?.map((item) => ({ label: item.name, value: item.id })),
            },
          };
          formInstance?.updateSchema([newSchema]);
        }
      },
      
      request: () => {
        return getCompanyOptions();

      },
      onSearch: debounce(async (keyword) => {
        schema.loading = true;
        const newSchema = {
          field: schema.field,
          componentProps: {
            options: [] as LabelValueOptions,
          },
        };
        formInstance?.updateSchema([newSchema]);
        const { items: result } = await Api.company
          .companyList({ pageSize: 100, name: keyword })
          .finally(() => (schema.loading = false));
        if (result) {
          newSchema.componentProps.options = result.map((item) => ({
            value: item.id,
            label: item.name,
          }));
        }
        formInstance?.updateSchema([newSchema]);
      }, 500),
    }),
  },
];

const getCompanyOptions = async (keyword?): Promise<LabelValueOptions> => {
  const { items: result } = await Api.company.companyList({ pageSize: 100 });
  return (
    result?.map((item) => ({
      label: item.name,
      value: item.id,
    })) || []
  );
};
